==> react-form-builder-4.22.0.tgz: package/lib/Select/Default/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo, useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../../prop-types';
import MoleculeSelectField from '@s-ui/react-molecule-select-field';
import MoleculeSelectOption from '@s-ui/react-molecule-dropdown-option';
import IconChevronDown from '../../Icons/IconChevronDown';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var DefaultSelect = function DefaultSelect(_ref) {
  var select = _ref.select,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      size = _ref.size,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[select.id];
  var alertMessages = alerts[select.id];
  var onChangeCallback = useCallback(function (evt, _ref2) {
    var value = _ref2.value;
    return onChange(select.id, value);
  }, [onChange, select]);

  var onBlurCallback = function onBlurCallback() {
    return onBlur(select.id);
  };

  var onFocusCallback = function onFocusCallback() {
    return onFocus(select.id);
  };

  var _select$datalist = select.datalist,
      datalist = _select$datalist === void 0 ? [] : _select$datalist; // transform constraints to props

  var constraints = select.constraints || [];
  var constraintsProps = {};
  constraintsProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property;

    if ((constraint == null ? void 0 : (_constraint$property = constraint.property) == null ? void 0 : _constraint$property.notnull) === '') {
      return _extends({}, acc, {
        required: true
      });
    } else {
      return acc;
    }
  }, constraintsProps);

  var selectProps = _extends({
    id: select.id,
    label: select.label,
    name: select.name,
    placeholder: select.hint,
    iconArrowDown: /*#__PURE__*/_jsx(IconChevronDown, {}),
    value: select.value || '',
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback,
    helpText: select.help,
    tabIndex: tabIndex
  }, select.disabled && {
    disabled: true
  }, select.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  }, {
    selectSize: size
  }, constraintsProps);

  if (selectProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: select.id,
    innerProps: _extends({}, selectProps, {
      datalist: datalist
    })
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsxs("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-DefaultSelect sui-FormBuilder-" + selectProps.id,
    children: [selectProps.label && /*#__PURE__*/_jsx("label", {
      className: "sui-FormBuilder-label",
      htmlFor: selectProps.id,
      children: selectProps.label
    }), /*#__PURE__*/_jsx(MoleculeSelectField, _extends({}, selectProps, rendererResponse, {
      children: datalist.map(function (data) {
        return /*#__PURE__*/_jsx(MoleculeSelectOption, {
          value: data.value,
          children: data.text
        }, data.value);
      })
    }))]
  });
};

DefaultSelect.displayName = 'DefaultSelect';
export default /*#__PURE__*/memo(DefaultSelect, createComponentMemo('select'));

==> react-form-builder-4.28.0.tgz: package/lib/Select/Default/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo, useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../../prop-types';
import MoleculeSelectField from '@s-ui/react-molecule-select-field';
import MoleculeSelectOption from '@s-ui/react-molecule-dropdown-option';
import IconChevronDown from '../../Icons/IconChevronDown';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var DefaultSelect = function DefaultSelect(_ref) {
  var select = _ref.select,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      size = _ref.size,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer,
      _ref$multiselection = _ref.multiselection,
      multiselection = _ref$multiselection === void 0 ? false : _ref$multiselection;
  var errorMessages = errors[select.id];
  var alertMessages = alerts[select.id];
  var onChangeCallback = useCallback(function (evt, _ref2) {
    var value = _ref2.value;
    return onChange(select.id, value);
  }, [onChange, select]);

  var onBlurCallback = function onBlurCallback() {
    return onBlur(select.id);
  };

  var onFocusCallback = function onFocusCallback() {
    return onFocus(select.id);
  };

  var _select$datalist = select.datalist,
      datalist = _select$datalist === void 0 ? [] : _select$datalist; // transform constraints to props

  var constraints = select.constraints || [];
  var constraintsProps = {};
  constraintsProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property;

    if ((constraint == null ? void 0 : (_constraint$property = constraint.property) == null ? void 0 : _constraint$property.notnull) === '') {
      return _extends({}, acc, {
        required: true
      });
    } else {
      return acc;
    }
  }, constraintsProps);
  var DEFAULT_SELECT_VALUE = multiselection ? [] : '';

  var selectProps = _extends({
    id: select.id,
    label: select.label,
    name: select.name,
    placeholder: select.hint,
    iconArrowDown: /*#__PURE__*/_jsx(IconChevronDown, {}),
    value: select.value || DEFAULT_SELECT_VALUE,
    onChange: onChangeCallback,
    onBlur: onBlurCallback,
    onFocus: onFocusCallback,
    helpText: select.help,
    tabIndex: tabIndex
  }, select.disabled && {
    disabled: true
  }, select.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  }, {
    selectSize: size
  }, constraintsProps);

  if (selectProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: select.id,
    innerProps: _extends({}, selectProps, {
      datalist: datalist
    })
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsxs("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-DefaultSelect sui-FormBuilder-" + selectProps.id,
    children: [selectProps.label && /*#__PURE__*/_jsx("label", {
      className: "sui-FormBuilder-label",
      htmlFor: selectProps.id,
      children: selectProps.label
    }), /*#__PURE__*/_jsx(MoleculeSelectField, _extends({}, selectProps, rendererResponse, {
      multiselection: multiselection,
      children: datalist.map(function (data) {
        return /*#__PURE__*/_jsx(MoleculeSelectOption, {
          value: data.value,
          children: data.text
        }, data.value);
      })
    }))]
  });
};

DefaultSelect.displayName = 'DefaultSelect';
export default /*#__PURE__*/memo(DefaultSelect, createComponentMemo('select'));
